==> physx-jni-0.4.0-sources.jar: physx/cooking/PxMeshPreprocessingFlags.java <==
package physx.cooking;

import physx.NativeObject;

public class PxMeshPreprocessingFlags extends NativeObject {

    protected PxMeshPreprocessingFlags() { }

    public static PxMeshPreprocessingFlags wrapPointer(long address) {
        return new PxMeshPreprocessingFlags(address);
    }
    
    protected PxMeshPreprocessingFlags(long address) {
        super(address);
    }

    // Constructors

    /**
     * @param flags WebIDL type: unsigned long
     */
    public PxMeshPreprocessingFlags(int flags) {
        address = _PxMeshPreprocessingFlags(flags);
    }
    private static native long _PxMeshPreprocessingFlags(int flags);

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Functions

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     * @return WebIDL type: boolean
     */
    public boolean isSet(int flag) {
        return _isSet(address, flag);
    }
    private static native boolean _isSet(long address, int flag);

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     */
    public void set(int flag) {
        _set(address, flag);
    }
    private static native void _set(long address, int flag);

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     */
    public void clear(int flag) {
        _clear(address, flag);
    }
    private static native void _clear(long address, int flag);

}

==> physx-jni-0.4.1-sources.jar: physx/cooking/PxMeshPreprocessingFlags.java <==
package physx.cooking;

import physx.NativeObject;

public class PxMeshPreprocessingFlags extends NativeObject {

    protected PxMeshPreprocessingFlags() { }

    public static PxMeshPreprocessingFlags wrapPointer(long address) {
        return address != 0L ? new PxMeshPreprocessingFlags(address) : null;
    }
    
    protected PxMeshPreprocessingFlags(long address) {
        super(address);
    }

    // Constructors

    /**
     * @param flags WebIDL type: unsigned long
     */
    public PxMeshPreprocessingFlags(int flags) {
        address = _PxMeshPreprocessingFlags(flags);
    }
    private static native long _PxMeshPreprocessingFlags(int flags);

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Functions

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     * @return WebIDL type: boolean
     */
    public boolean isSet(int flag) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return _isSet(address, flag);
    }
    private static native boolean _isSet(long address, int flag);

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     */
    public void set(int flag) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _set(address, flag);
    }
    private static native void _set(long address, int flag);

    /**
     * @param flag WebIDL type: {@link PxMeshPreprocessingFlagEnum} [enum]
     */
    public void clear(int flag) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _clear(address, flag);
    }
    private static native void _clear(long address, int flag);

}
